From: "Paul E. McKenney" <paul...@linux.vnet.ibm.com>

This commit makes the torture scripts a bit more RCU-independent.

Signed-off-by: Paul E. McKenney <paul...@linux.vnet.ibm.com>
---
 tools/testing/selftests/rcutorture/bin/functions.sh | 12 ++++++------
 tools/testing/selftests/rcutorture/bin/kvm.sh       |  5 +++--
 2 files changed, 9 insertions(+), 8 deletions(-)

diff --git a/tools/testing/selftests/rcutorture/bin/kvm.sh 
b/tools/testing/selftests/rcutorture/bin/kvm.sh
index 73c586f6bdf6..2f9605ed5b58 100644
--- a/tools/testing/selftests/rcutorture/bin/kvm.sh
+++ b/tools/testing/selftests/rcutorture/bin/kvm.sh
@@ -114,7 +114,7 @@ do
                shift
                ;;
        --interactive)
-               RCU_QEMU_INTERACTIVE=1; export RCU_QEMU_INTERACTIVE
+               TORTURE_QEMU_INTERACTIVE=1; export TORTURE_QEMU_INTERACTIVE
                ;;
        --kmake-arg)
                checkarg --kmake-arg "(kernel make arguments)" $# "$2" '.*' 
'^error$'
@@ -378,7 +378,8 @@ then
        echo TORTURE_INITRD="$TORTURE_INITRD; export TORTURE_INITRD"
        echo TORTURE_KMAKE_ARG="$TORTURE_KMAKE_ARG; export TORTURE_KMAKE_ARG"
        echo RCU_QEMU_CMD="$RCU_QEMU_CMD; export RCU_QEMU_CMD"
-       echo RCU_QEMU_INTERACTIVE="$RCU_QEMU_INTERACTIVE; export 
RCU_QEMU_INTERACTIVE"
+       echo TORTURE_QEMU_INTERACTIVE="$TORTURE_QEMU_INTERACTIVE;
+               export TORTURE_QEMU_INTERACTIVE"
        echo RCU_QEMU_MAC="$RCU_QEMU_MAC; export RCU_QEMU_MAC"
        echo "mkdir -p "$resdir" || :"
        echo "mkdir $resdir/$ds"
diff --git a/tools/testing/selftests/rcutorture/bin/functions.sh 
b/tools/testing/selftests/rcutorture/bin/functions.sh
index 9b17e810ddc3..623939cf814e 100644
--- a/tools/testing/selftests/rcutorture/bin/functions.sh
+++ b/tools/testing/selftests/rcutorture/bin/functions.sh
@@ -107,14 +107,14 @@ identify_qemu () {
 # identify_qemu_append qemu-cmd
 #
 # Output arguments for the qemu "-append" string based on CPU type
 # and the RCU_QEMU_INTERACTIVE environment variable.
 identify_qemu_append () {
        case "$1" in
        qemu-system-x86_64|qemu-system-i386)
                echo noapic selinux=0 initcall_debug debug
                ;;
        esac
-       if test -n "$RCU_QEMU_INTERACTIVE"
+       if test -n "$TORTURE_QEMU_INTERACTIVE"
        then
                echo root=/dev/sda
        else
@@ -125,7 +125,7 @@ identify_qemu_append () {
 # identify_qemu_args qemu-cmd serial-file
 #
 # Output arguments for qemu arguments based on the RCU_QEMU_MAC
 # and RCU_QEMU_INTERACTIVE environment variables.
 identify_qemu_args () {
        case "$1" in
        qemu-system-x86_64|qemu-system-i386)
@@ -133,17 +133,17 @@ identify_qemu_args () {
        qemu-system-ppc64)
                echo -enable-kvm -M pseries -cpu POWER7 -nodefaults
                echo -device spapr-vscsi
-               if test -n "$RCU_QEMU_INTERACTIVE" -a -n "$RCU_QEMU_MAC"
+               if test -n "$TORTURE_QEMU_INTERACTIVE" -a -n "$RCU_QEMU_MAC"
                then
                        echo -device spapr-vlan,netdev=net0,mac=$RCU_QEMU_MAC
                        echo -netdev bridge,br=br0,id=net0
-               elif test -n "$RCU_QEMU_INTERACTIVE"
+               elif test -n "$TORTURE_QEMU_INTERACTIVE"
                then
                        echo -net nic -net user
                fi
                ;;
        esac
-       if test -n "$RCU_QEMU_INTERACTIVE"
+       if test -n "$TORTURE_QEMU_INTERACTIVE"
        then
                echo -monitor stdio -serial pty -S
        else
@@ -107,14 +107,14 @@ identify_qemu () {
 #
 # Output arguments for the qemu "-append" string based on CPU type
-# and the RCU_QEMU_INTERACTIVE environment variable.
+# and the TORTURE_QEMU_INTERACTIVE environment variable.
 identify_qemu_append () {
        case "$1" in
@@ -125,7 +125,7 @@ identify_qemu_append () {
 #
 # Output arguments for qemu arguments based on the RCU_QEMU_MAC
-# and RCU_QEMU_INTERACTIVE environment variables.
+# and TORTURE_QEMU_INTERACTIVE environment variables.
 identify_qemu_args () {
        case "$1" in
-- 
1.8.1.5

--
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Please read the FAQ at  http://www.tux.org/lkml/

Reply via email to